@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: shakespeare
 version: 2.0.7
-id: shakespeare-2.0.7-423d40cf84610c6e09dcfa0707b6b283
-key: shake_EuK2lX4rZQwEyZc4T7SYzq
+id: shakespeare-2.0.7-39cc4f42107716d9e8a539beb0a84dc6
+key: shake_5C0sDlUm7TL3jw8eYGgvyw
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -33,9 +33,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.7
 library-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.7
 data-dir: /usr/share/arm-linux-ghc-7.10.3/shakespeare-2.0.7
-hs-libraries: HSshakespeare-2.0.7-EuK2lX4rZQwEyZc4T7SYzq
+hs-libraries: HSshakespeare-2.0.7-5C0sDlUm7TL3jw8eYGgvyw
 depends:
-    aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
@@ -46,7 +46,7 @@ depends:
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
-    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
+    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
